# Relese Changelog
## [0.1.15] - 2025-9-1
### Target
- Saved for StreamResponser tool_exec_on_stream mode, next release will be abolished
### Changed
- Improve French translation (#377).
### Fixed
- Fix finish_reason judge logic

## [0.1.15] - 2025-8-31
### Target
- First complete version 
